pywr.recorders.RollingMeanFlowNodeRecorder
==========================================

.. currentmodule:: pywr.recorders

.. autoclass:: RollingMeanFlowNodeRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RollingMeanFlowNodeRecorder.after
      ~RollingMeanFlowNodeRecorder.aggregated_value
      ~RollingMeanFlowNodeRecorder.before
      ~RollingMeanFlowNodeRecorder.finish
      ~RollingMeanFlowNodeRecorder.load
      ~RollingMeanFlowNodeRecorder.register
      ~RollingMeanFlowNodeRecorder.reset
      ~RollingMeanFlowNodeRecorder.setup
      ~RollingMeanFlowNodeRecorder.unregister
      ~RollingMeanFlowNodeRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RollingMeanFlowNodeRecorder.agg_func
      ~RollingMeanFlowNodeRecorder.children
      ~RollingMeanFlowNodeRecorder.comment
      ~RollingMeanFlowNodeRecorder.data
      ~RollingMeanFlowNodeRecorder.days
      ~RollingMeanFlowNodeRecorder.epsilon
      ~RollingMeanFlowNodeRecorder.ignore_nan
      ~RollingMeanFlowNodeRecorder.is_constraint
      ~RollingMeanFlowNodeRecorder.is_objective
      ~RollingMeanFlowNodeRecorder.model
      ~RollingMeanFlowNodeRecorder.name
      ~RollingMeanFlowNodeRecorder.node
      ~RollingMeanFlowNodeRecorder.parents
      ~RollingMeanFlowNodeRecorder.timesteps
   
   